@@ -17,43 +17,40 @@
 #include <QRadioButton>
 #include <QSpacerItem>
 
-BehaviorSettingsPage::BehaviorSettingsPage(const QUrl& url, QWidget* parent) :
-    SettingsPageBase(parent),
-    m_url(url),
-    m_localViewProps(nullptr),
-    m_globalViewProps(nullptr),
-    m_showToolTips(nullptr),
-    m_showSelectionToggle(nullptr),
-    m_naturalSorting(nullptr),
-    m_caseSensitiveSorting(nullptr),
-    m_caseInsensitiveSorting(nullptr),
-    m_renameInline(nullptr),
-    m_useTabForSplitViewSwitch(nullptr)
+BehaviorSettingsPage::BehaviorSettingsPage(const QUrl &url, QWidget *parent)
+    : SettingsPageBase(parent)
+    , m_url(url)
+    , m_localViewProps(nullptr)
+    , m_globalViewProps(nullptr)
+    , m_showToolTips(nullptr)
+    , m_showSelectionToggle(nullptr)
+    , m_naturalSorting(nullptr)
+    , m_caseSensitiveSorting(nullptr)
+    , m_caseInsensitiveSorting(nullptr)
+    , m_renameInline(nullptr)
+    , m_useTabForSplitViewSwitch(nullptr)
 {
-    QFormLayout* topLayout = new QFormLayout(this);
-
+    QFormLayout *topLayout = new QFormLayout(this);
 
     // View properties
     m_globalViewProps = new QRadioButton(i18nc("@option:radio", "Use common display style for all folders"));
     m_localViewProps = new QRadioButton(i18nc("@option:radio", "Remember display style for each folder"));
     m_localViewProps->setToolTip(i18nc("@info", "Dolphin will create a hidden .directory file in each folder you change view properties for."));
 
-    QButtonGroup* viewGroup = new QButtonGroup(this);
+    QButtonGroup *viewGroup = new QButtonGroup(this);
     viewGroup->addButton(m_globalViewProps);
     viewGroup->addButton(m_localViewProps);
     topLayout->addRow(i18nc("@title:group", "View: "), m_globalViewProps);
     topLayout->addRow(QString(), m_localViewProps);
 
-
     topLayout->addItem(new QSpacerItem(0, Dolphin::VERTICAL_SPACER_HEIGHT, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
-
     // Sorting properties
     m_naturalSorting = new QRadioButton(i18nc("option:radio", "Natural"));
     m_caseInsensitiveSorting = new QRadioButton(i18nc("option:radio", "Alphabetical, case insensitive"));
     m_caseSensitiveSorting = new QRadioButton(i18nc("option:radio", "Alphabetical, case sensitive"));
 
-    QButtonGroup* sortingModeGroup = new QButtonGroup(this);
+    QButtonGroup *sortingModeGroup = new QButtonGroup(this);
     sortingModeGroup->addButton(m_naturalSorting);
     sortingModeGroup->addButton(m_caseInsensitiveSorting);
     sortingModeGroup->addButton(m_caseSensitiveSorting);
@@ -61,9 +58,19 @@ BehaviorSettingsPage::BehaviorSettingsPage(const QUrl& url, QWidget* parent) :
     topLayout->addRow(QString(), m_caseInsensitiveSorting);
     topLayout->addRow(QString(), m_caseSensitiveSorting);
 
-
+    // Split Views
     topLayout->addItem(new QSpacerItem(0, Dolphin::VERTICAL_SPACER_HEIGHT, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
+    // 'Switch between panes of split views with tab key'
+    m_useTabForSplitViewSwitch = new QCheckBox(i18nc("option:check split view panes", "Switch between panes with Tab key"));
+    topLayout->addRow(i18nc("@title:group", "Split view: "), m_useTabForSplitViewSwitch);
+
+    // 'Close active pane when turning off split view'
+    m_closeActiveSplitView = new QCheckBox(i18nc("option:check", "Turning off split view closes active pane"));
+    topLayout->addRow(QString(), m_closeActiveSplitView);
+    m_closeActiveSplitView->setToolTip(i18n("When deactivated, turning off split view will close the inactive pane"));
+
+    topLayout->addItem(new QSpacerItem(0, Dolphin::VERTICAL_SPACER_HEIGHT, QSizePolicy::Fixed, QSizePolicy::Fixed));
 
 #if HAVE_BALOO
     // 'Show tooltips'
@@ -83,15 +90,6 @@ BehaviorSettingsPage::BehaviorSettingsPage(const QUrl& url, QWidget* parent) :
     m_renameInline = new QCheckBox(i18nc("option:check", "Rename inline"));
     topLayout->addRow(QString(), m_renameInline);
 
-    // 'Switch between panes of split views with tab key'
-    m_useTabForSplitViewSwitch = new QCheckBox(i18nc("option:check", "Switch between split views panes with tab key"));
-    topLayout->addRow(QString(), m_useTabForSplitViewSwitch);
-
-    // 'Close active pane when turning off split view'
-    m_closeActiveSplitView = new QCheckBox(i18nc("option:check", "Turning off split view closes active pane"));
-    topLayout->addRow(QString(), m_closeActiveSplitView);
-    m_closeActiveSplitView->setToolTip(i18n("When deactivated, turning off split view will close the inactive pane"));
-
     loadSettings();
 
     connect(m_localViewProps, &QRadioButton::toggled, this, &BehaviorSettingsPage::changed);
@@ -114,8 +112,8 @@ BehaviorSettingsPage::~BehaviorSettingsPage()
 
 void BehaviorSettingsPage::applySettings()
 {
-    GeneralSettings* settings = GeneralSettings::self();
-    ViewProperties props(m_url);  // read current view properties
+    GeneralSettings *settings = GeneralSettings::self();
+    ViewProperties props(m_url); // read current view properties
 
     const bool useGlobalViewProps = m_globalViewProps->isChecked();
     settings->setGlobalViewProps(useGlobalViewProps);
@@ -141,7 +139,7 @@ void BehaviorSettingsPage::applySettings()
 
 void BehaviorSettingsPage::restoreDefaults()
 {
-    GeneralSettings* settings = GeneralSettings::self();
+    GeneralSettings *settings = GeneralSettings::self();
     settings->useDefaults(true);
     loadSettings();
     settings->useDefaults(false);
