@@ -10,16 +10,16 @@
 
 #include <KIO/FileSystemFreeSpaceJob>
 
-MountPointObserver::MountPointObserver(const QUrl& url, QObject* parent) :
-    QObject(parent),
-    m_url(url),
-    m_referenceCount(0)
+MountPointObserver::MountPointObserver(const QUrl &url, QObject *parent)
+    : QObject(parent)
+    , m_url(url)
+    , m_referenceCount(0)
 {
 }
 
-MountPointObserver* MountPointObserver::observerForUrl(const QUrl& url)
+MountPointObserver *MountPointObserver::observerForUrl(const QUrl &url)
 {
-    MountPointObserver* observer = MountPointObserverCache::instance()->observerForUrl(url);
+    MountPointObserver *observer = MountPointObserverCache::instance()->observerForUrl(url);
     return observer;
 }
 
@@ -28,12 +28,12 @@ void MountPointObserver::update()
     if (m_referenceCount == 0) {
         delete this;
     } else {
-        KIO::FileSystemFreeSpaceJob* job = KIO::fileSystemFreeSpace(m_url);
+        KIO::FileSystemFreeSpaceJob *job = KIO::fileSystemFreeSpace(m_url);
         connect(job, &KIO::FileSystemFreeSpaceJob::result, this, &MountPointObserver::freeSpaceResult);
     }
 }
 
-void MountPointObserver::freeSpaceResult(KIO::Job* job, KIO::filesize_t size, KIO::filesize_t available)
+void MountPointObserver::freeSpaceResult(KIO::Job *job, KIO::filesize_t size, KIO::filesize_t available)
 {
     if (!job->error()) {
         Q_EMIT spaceInfoChanged(size, available);
